@@ -1,5 +1,5 @@
 //
-// GOATTRACKER v2.67
+// GOATTRACKER v2.68
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -39,8 +39,8 @@ int exitprogram = 0;
 int eacolumn = 0;
 int eamode = 0;
 
-int keypreset = KEY_TRACKER;
-int playerversion = 0;
+unsigned keypreset = KEY_TRACKER;
+unsigned playerversion = 0;
 int fileformat = FORMAT_PRG;
 int zeropageadr = 0xfc;
 int playeradr = 0x1000;
@@ -67,16 +67,16 @@ unsigned hardsidbufplayback = 400;
 
 char *configptr;
 char configbuf[MAX_PATHNAME];
-unsigned char loadedsongfilename[MAX_FILENAME];
-unsigned char songfilename[MAX_FILENAME];
-unsigned char songfilter[MAX_FILENAME];
-unsigned char songpath[MAX_PATHNAME];
-unsigned char instrfilename[MAX_FILENAME];
-unsigned char instrfilter[MAX_FILENAME];
-unsigned char instrpath[MAX_PATHNAME];
-unsigned char packedpath[MAX_PATHNAME];
+char loadedsongfilename[MAX_FILENAME];
+char songfilename[MAX_FILENAME];
+char songfilter[MAX_FILENAME];
+char songpath[MAX_PATHNAME];
+char instrfilename[MAX_FILENAME];
+char instrfilter[MAX_FILENAME];
+char instrpath[MAX_PATHNAME];
+char packedpath[MAX_PATHNAME];
 
-char *programname = "GoatTracker v2.67";
+char *programname = "GoatTracker v2.68";
                                       
 char textbuffer[MAX_PATHNAME];
 
@@ -113,12 +113,12 @@ int main(int argc, char **argv)
     getparam(configfile, &hardsid);
     getparam(configfile, &sidmodel);
     getparam(configfile, &ntsc);
-    getparam(configfile, &fileformat);
-    getparam(configfile, &playeradr);
-    getparam(configfile, &zeropageadr);
+    getparam(configfile, (unsigned *)&fileformat);
+    getparam(configfile, (unsigned *)&playeradr);
+    getparam(configfile, (unsigned *)&zeropageadr);
     getparam(configfile, &playerversion);
     getparam(configfile, &keypreset);
-    getparam(configfile, &stepsize);
+    getparam(configfile, (unsigned *)&stepsize);
     getparam(configfile, &multiplier);
     getparam(configfile, &catweasel);
     getparam(configfile, &adparam);
@@ -166,7 +166,7 @@ int main(int argc, char **argv)
         printtext(0,y++,15,"/Exx Set emulated SID model (0 = 6581 1 = 8580) DEFAULT=6581");
         printtext(0,y++,15,"/Fxx Set custom SID clock cycles per second (0 = use PAL/NTSC default)");
         printtext(0,y++,15,"/Hxx Use HardSID (0 = off, 1 = HardSID ID0 2 = HardSID ID1 etc.)");
-        printtext(0,y++,15,"/Ixx Set reSID interpolation (0 = off, 1 = on) DEFAULT=off");
+        printtext(0,y++,15,"/Ixx Set reSID interpolation (0 = off, 1 = on, 2 = distortion, 3 = distortion & on) DEFAULT=off");
         printtext(0,y++,15,"/Kxx Note-entry mode (0 = PROTRACKER 1 = DMC) DEFAULT=PROTRK.");
         printtext(0,y++,15,"/Lxx SID memory location in hex. DEFAULT=D400");
         printtext(0,y++,15,"/Mxx Set sound mixing rate DEFAULT=44100");
@@ -176,7 +176,7 @@ int main(int argc, char **argv)
         printtext(0,y++,15,"/Txx Set HardSID interactive mode sound buffer length in milliseconds DEFAULT=20, max.buffering=0");
         printtext(0,y++,15,"/Uxx Set HardSID playback mode sound buffer length in milliseconds DEFAULT=400, max.buffering=0");
         printtext(0,y++,15,"/Vxx Set finevibrato conversion (0 = off, 1 = on) DEFAULT=1");
-        printtext(0,y++,15,"/Zxx Set random reSID write delay in cycles (0 = off) DEFAULT=off");
+        printtext(0,y++,15,"/Zxx Set random reSID write delay in cycles (0 = off) DEFAULT=0");
         printtext(0,y++,15,"/N   Use NTSC timing");
         printtext(0,y++,15,"/P   Use PAL timing (DEFAULT)");
         printtext(0,y++,15,"/W   Write sound output to a file SIDAUDIO.RAW");
@@ -325,6 +325,9 @@ int main(int argc, char **argv)
     waitkeymouse();
     docommand();
   }
+  
+  // Shutdown sound output now
+  sound_uninit();
 
   // Save configuration
   #ifndef __WIN32__
@@ -355,7 +358,7 @@ int main(int argc, char **argv)
                         ";Speed multiplier (0 = 25Hz, 1 = 1X, 2 = 2X etc.)\n%d\n\n"
                         ";Use CatWeasel SID (0 = off, 1 = on)\n%d\n\n"
                         ";Hardrestart ADSR parameter\n$%04x\n\n"
-                        ";reSID interpolation (0 = off, 1 = on)\n%d\n\n"
+                        ";reSID interpolation (0 = off, 1 = on, 2 = distortion, 3 = distortion & on)\n%d\n\n"
                         ";Hexadecimal pattern display (0 = off, 1 = on)\n%d\n\n"
                         ";SID baseaddress\n$%04x\n\n"
                         ";Finevibrato mode (0 = off, 1 = on)\n%d\n\n"
@@ -1224,7 +1227,7 @@ void editadsr(void)
   }
 }
 
-void getparam(FILE *handle, int *value)
+void getparam(FILE *handle, unsigned *value)
 {
   for (;;)
   {
